import { __decorate } from 'tslib';
import { forwardRef, EventEmitter, Input, Output, Component, ViewChild, ViewEncapsulation, NgModule } from '@angular/core';
import { isNullOrUndefined, Toolkit2 } from '@angular-boot/util';
import { Subject, fromEvent } from 'rxjs';
import { map, debounceTime, takeUntil } from 'rxjs/operators';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { CommonModule } from '@angular/common';

var noop = function () {
};
var ɵ0 = noop;
var CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return AutoSearchInputComponent; }),
    multi: true
};
var AutoSearchInputComponent = /** @class */ (function () {
    function AutoSearchInputComponent() {
        this.myId = null;
        this.currentValue = new EventEmitter();
        this.unsubscribe1$ = new Subject();
        this.unsubscribe2$ = new Subject();
        // -------------[(ngModel)]
        // The internal data model
        this.innerValue = '';
        // Placeholders for the callbacks which are later provided
        // by the Control Value Accessor
        this.onTouchedCallback = noop;
        this.onChangeCallback = noop;
    }
    AutoSearchInputComponent.prototype.ngOnInit = function () {
        if (isNullOrUndefined(this.myId)) {
            this.myId = Toolkit2.Common.create().uuidv4();
        }
        if (isNullOrUndefined(this.debounceTime)) {
            this.debounceTime = 500;
        }
    };
    AutoSearchInputComponent.prototype.inputHandle = function () {
        var _this = this;
        var input = document.getElementById(this.myId);
        if (input) {
            var example1 = fromEvent(input, 'keyup')
                .pipe(map(function (i) { return i.currentTarget['value']; }));
            var example2 = fromEvent(input, 'paste')
                .pipe(map(function (i) { return i.currentTarget['value']; }));
            var debouncedInputOnKeyup = example1.pipe(debounceTime(this.debounceTime));
            var debouncedInputOnPaste = example2.pipe(debounceTime(this.debounceTime));
            if (debouncedInputOnKeyup) {
                debouncedInputOnKeyup
                    .pipe(takeUntil(this.unsubscribe1$))
                    .subscribe(function (val) {
                    // console.log(`Debounced Input: ${val}`);
                    _this.currentValue.emit(val);
                });
            }
            if (debouncedInputOnPaste) {
                debouncedInputOnPaste
                    .pipe(takeUntil(this.unsubscribe2$))
                    .subscribe(function (val) {
                    // console.log(`Debounced Input: ${val}`);
                    // alert(2 + '  ' + val);
                    setTimeout(function () {
                        _this.currentValue.emit(_this.value);
                    }, 10);
                });
            }
        }
    };
    AutoSearchInputComponent.prototype.ngAfterViewInit = function () {
        this.inputHandle();
    };
    Object.defineProperty(AutoSearchInputComponent.prototype, "value", {
        // get accessor
        get: function () {
            return this.innerValue;
        },
        // set accessor including call the onchange callback
        set: function (v) {
            if (v !== this.innerValue) {
                this.innerValue = v;
                this.onChangeCallback(v);
            }
        },
        enumerable: true,
        configurable: true
    });
    ;
    // Set touched on blur
    AutoSearchInputComponent.prototype.onBlur = function () {
        this.onTouchedCallback();
    };
    // From ControlValueAccessor interface
    AutoSearchInputComponent.prototype.registerOnChange = function (fn) {
        this.onChangeCallback = fn;
    };
    // From ControlValueAccessor interface
    AutoSearchInputComponent.prototype.registerOnTouched = function (fn) {
        this.onTouchedCallback = fn;
    };
    AutoSearchInputComponent.prototype.setDisabledState = function (isDisabled) {
    };
    // From ControlValueAccessor interface
    AutoSearchInputComponent.prototype.writeValue = function (value) {
        if (value !== this.innerValue) {
            this.innerValue = value;
        }
    };
    AutoSearchInputComponent.prototype.ngOnDestroy = function () {
        this.unsubscribe1$.next();
        this.unsubscribe1$.complete();
        this.unsubscribe2$.next();
        this.unsubscribe2$.complete();
    };
    __decorate([
        Input()
    ], AutoSearchInputComponent.prototype, "placeholder", void 0);
    __decorate([
        Input()
    ], AutoSearchInputComponent.prototype, "cssClass", void 0);
    __decorate([
        Input()
    ], AutoSearchInputComponent.prototype, "myId", void 0);
    __decorate([
        Input()
    ], AutoSearchInputComponent.prototype, "debounceTime", void 0);
    __decorate([
        Output()
    ], AutoSearchInputComponent.prototype, "currentValue", void 0);
    AutoSearchInputComponent = __decorate([
        Component({
            selector: 'nbw-auto-search-input',
            template: "<input type=\"text\" [placeholder]=\"placeholder\" [id]=\"myId\"\n       [(ngModel)]=\"value\"\n       [class]=\"cssClass\" />\n",
            providers: [CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR],
            styles: [""]
        })
    ], AutoSearchInputComponent);
    return AutoSearchInputComponent;
}());

var CarouselComponent = /** @class */ (function () {
    function CarouselComponent(_ActivatedRoute) {
        this._ActivatedRoute = _ActivatedRoute;
        this.onClose = new EventEmitter();
        // this._ActivatedRoute.paramMap.subscribe((params: ParamMap) => {
        //   this.replicationElementId = params.get('replic_id');
        // });
        this.replicationElementId = this._ActivatedRoute.snapshot.paramMap.get('replic_id');
    }
    CarouselComponent.prototype.ngOnInit = function () {
        this.show = true;
        this.myId = 'carousel_' + Toolkit2.Common.create().uuidv4();
    };
    CarouselComponent.prototype.goBack = function () {
        this.onBack();
        if (this.onLeaveHistoryBack) {
            window.history.back();
        }
    };
    CarouselComponent.prototype.onBack = function () {
        this.show = false;
        // document.getElementById(this.replicationElementId).style.display = 'block';
        var elList = document.getElementsByClassName(this.replicationElementId);
        for (var i = 0; i < elList.length; i++) {
            elList.item(i).style.display = 'block';
        }
        this.onClose.emit(true);
    };
    CarouselComponent.prototype.ngAfterViewInit = function () {
        // document.getElementById(this.replicationElementId).style.display = 'none';
        var elList = document.getElementsByClassName(this.replicationElementId);
        Array.prototype.forEach.call(elList, function (slide, index) {
            elList.item(index).style.display = 'none';
        });
        // for(let i= 0; i< elList.length; i++) {
        //   elList.item(i).style.display = 'none';
        // }
    };
    CarouselComponent.prototype.ngOnDestroy = function () {
        this.onBack();
    };
    CarouselComponent.ctorParameters = function () { return [
        { type: ActivatedRoute }
    ]; };
    __decorate([
        Input()
    ], CarouselComponent.prototype, "title", void 0);
    __decorate([
        Input()
    ], CarouselComponent.prototype, "onLeaveHistoryBack", void 0);
    __decorate([
        Output()
    ], CarouselComponent.prototype, "onClose", void 0);
    CarouselComponent = __decorate([
        Component({
            selector: 'nbw-carousel',
            template: "<div *ngIf=\"show\">\n  <button (click)=\"goBack()\" class=\"nbw-carousel-back-btn\">\u0628\u0627\u0632\u06AF\u0634\u062A</button>\n  <ng-content></ng-content>\n</div>\n",
            styles: [""]
        })
    ], CarouselComponent);
    return CarouselComponent;
}());

var JsonPrintComponent = /** @class */ (function () {
    function JsonPrintComponent() {
    }
    JsonPrintComponent.prototype.ngOnInit = function () {
    };
    JsonPrintComponent.prototype.ngOnChanges = function (changes) {
        if (!isNullOrUndefined(this.json_In) && this.json_In !== '') {
            this.output(this.syntaxHighlight(this.json_In));
        }
    };
    JsonPrintComponent.prototype.output = function (inp) {
        // this.jsonPrintDiv.nativeElement.appendChild(
        //   document.createElement('pre')
        //   // .setAttribute('width', '60')
        // ).innerHTML = inp;
        this.jsonPrintPre.nativeElement.innerHTML = inp;
    };
    JsonPrintComponent.prototype.syntaxHighlight = function (json) {
        json = json.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;');
        return json.replace(/("(\\u[a-zA-Z0-9]{4}|\\[^u]|[^\\"])*"(\s*:)?|\b(true|false|null)\b|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?)/g, function (match) {
            var cls = 'number';
            if (/^"/.test(match)) {
                if (/:$/.test(match)) {
                    cls = 'key';
                }
                else {
                    cls = 'string';
                }
            }
            else if (/true|false/.test(match)) {
                cls = 'boolean';
            }
            else if (/null/.test(match)) {
                cls = 'null';
            }
            return '<span class="' + cls + '">' + match + '</span>';
        });
    };
    __decorate([
        Input()
    ], JsonPrintComponent.prototype, "json_In", void 0);
    __decorate([
        ViewChild('jsonPrintPre', { static: true })
    ], JsonPrintComponent.prototype, "jsonPrintPre", void 0);
    JsonPrintComponent = __decorate([
        Component({
            selector: 'nbw-json-print',
            template: "\n      <div>\n          <ng-content></ng-content>\n          <pre #jsonPrintPre></pre>\n      </div>",
            encapsulation: ViewEncapsulation.ShadowDom,
            styles: [".word-wrap{white-space:pre-wrap;white-space:-moz-pre-wrap;white-space:-pre-wrap;white-space:-o-pre-wrap;word-wrap:break-word}pre{outline:#ccc solid 1px;padding:5px;margin:5px;overflow-x:hidden;height:auto;white-space:pre-wrap;white-space:-moz-pre-wrap;white-space:-pre-wrap;white-space:-o-pre-wrap;word-wrap:break-word}.string{color:green}.number{color:#ff8c00}.boolean{color:#00f}.null{color:#ff00ff}.key{color:brown}"]
        })
    ], JsonPrintComponent);
    return JsonPrintComponent;
}());

var ModalUtil = /** @class */ (function () {
    function ModalUtil() {
    }
    ModalUtil.generateModalId = function () {
        return 'modal_' + Toolkit2.Common.create().uuidv4();
    };
    ModalUtil.showModal = function (modalId, appendToBodyOnShow) {
        // $('#' + modalId).modal('show');
        // if ($('#' + modalId).parent().get(0).tagName != 'BODY')
        //   $('.modal-backdrop').insertAfter($('#' + modalId));
        if (appendToBodyOnShow !== false) {
            if ($('body>div#' + modalId).length > 0) {
                $('#' + modalId).modal('show');
            }
            else {
                $('#' + modalId).appendTo('body').modal('show'); // removes Original
            }
            // $('#' + modalId).clone(false, true).appendTo('body').modal('show'); // preserve original but not works scripts
            // //OR
            // $('body').append($('#' + modalId).clone()).modal('show'); // preserve original but not works scripts
        }
        else {
            $('#' + modalId).modal('show');
        }
    };
    ModalUtil.hideModal = function (modalId, removeFromDom) {
        $('#' + modalId).modal('hide');
        if (removeFromDom === true) {
            ModalUtil.removeModalFromDom(modalId);
        }
        // setTimeout(() => {
        //   $('#' + modalId).remove();
        // }, 1000);
    };
    ModalUtil.removeModalFromDom = function (modalId) {
        $('body>#' + modalId).remove();
        $('body>.modal-backdrop').remove();
    };
    return ModalUtil;
}());

var WindowMediaUtil = /** @class */ (function () {
    function WindowMediaUtil() {
    }
    WindowMediaUtil.isXl = function () {
        if (WindowMediaUtil.matchXl()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.isLg = function () {
        if (!WindowMediaUtil.matchXl() && WindowMediaUtil.matchLg()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.isMd = function () {
        if (!WindowMediaUtil.matchXl() && !WindowMediaUtil.matchLg() && WindowMediaUtil.matchMd()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.isSm = function () {
        if (!WindowMediaUtil.matchXl() && !WindowMediaUtil.matchLg() && !WindowMediaUtil.matchMd() && WindowMediaUtil.matchSm()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.isXs = function () {
        if (!WindowMediaUtil.matchXl() && !WindowMediaUtil.matchLg() && !WindowMediaUtil.matchMd() && !WindowMediaUtil.matchSm() && WindowMediaUtil.matchXs()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.isSmOrSmaller = function () {
        if (WindowMediaUtil.isSm() || WindowMediaUtil.isXs()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.isMdOrSmaller = function () {
        if (WindowMediaUtil.isMd() || WindowMediaUtil.isSm() || WindowMediaUtil.isXs()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.isLgOrSmaller = function () {
        if (WindowMediaUtil.isLg() || WindowMediaUtil.isMd() || WindowMediaUtil.isSm() || WindowMediaUtil.isXs()) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.matchXl = function () {
        if (window.matchMedia('(min-width: 1200px)').matches) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.matchLg = function () {
        if (window.matchMedia('(min-width: 992px)').matches) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.matchMd = function () {
        if (window.matchMedia('(min-width: 768px)').matches) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.matchSm = function () {
        if (window.matchMedia('(min-width: 576px)').matches) {
            return true;
        }
        return false;
    };
    WindowMediaUtil.matchXs = function () {
        if (window.matchMedia('(min-width: 0px)').matches) {
            return true;
        }
        return false;
    };
    return WindowMediaUtil;
}());

var WindowMedias = /** @class */ (function () {
    function WindowMedias() {
    }
    return WindowMedias;
}());

var ModalSize;
(function (ModalSize) {
    ModalSize["DEFAULT"] = "DEFAULT";
    ModalSize["LARGE"] = "LARGE";
    ModalSize["SMALL"] = "SMALL";
    ModalSize["X_LARGE"] = "X_LARGE";
    ModalSize["FULL_SCREEN"] = "FULL_SCREEN";
    ModalSize["FULL_WIDTH"] = "FULL_WIDTH";
    ModalSize["CUSTOM_WIDTH"] = "CUSTOM_WIDTH";
})(ModalSize || (ModalSize = {}));

var ModalComponent = /** @class */ (function () {
    function ModalComponent() {
        this.MyModalSize = ModalSize;
        // private _customWidthPercent: WindowMedias<number> = new WindowMedias<number>();
        this.hasHeader = true;
        this.hasFooter = true;
        this.myId = null;
        this.autoShow = true;
        this.modalSize = ModalSize.DEFAULT;
        this.customWidthPercent = new WindowMedias();
        // set customWidthPercent(val: WindowMedias<number>) {
        //   this._customWidthPercent = val;
        //   if (this.hasCustomWidth === true) {
        //     this.handleCustomWith();
        //   }
        // }
        //
        // get customWidthPercent() {
        //   return this._customWidthPercent;
        // }
        this.historyBackOnClose = false;
        this.dataBackdrop = true;
        this.displayBackdrop = true;
        this.scrollLargeContents = true;
        this.modalDialogCentered = false;
        this.fade = true;
        this.onClose = new EventEmitter();
        this.onShow = new EventEmitter();
        this.onShown = new EventEmitter();
        this.myModalSizeClass = '';
        this.hasCustomWidth = false;
        this.defaultWidthPercent = 50;
        this.reset();
    }
    ModalComponent.prototype.reset = function () {
        this.isShow = false;
        this.isShown = false;
    };
    ModalComponent.prototype.ngOnInit = function () {
        this.reset();
        if (isNullOrUndefined(this.myId)) {
            this.myId = ModalUtil.generateModalId();
        }
        // alert(this.myId);
        //
        // $('.modal').modal({
        //
        // });
    };
    ModalComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        // $.fn.modal.Constructor.prototype.enforceFocus = function () {
        //   let modal_this = this;
        //   $(document).on('focusin.modal', function (e) {
        //     if (modal_this.$element[0] !== e.target && !modal_this.$element.has(e.target).length
        //       // add whatever conditions you need here:
        //       &&
        //       !$(e.target.parentNode).hasClass('cke_dialog_ui_input_select') && !$(e.target.parentNode).hasClass('cke_dialog_ui_input_text')) {
        //       modal_this.$element.focus();
        //     }
        //   });
        // };
        var that = this;
        if (this.autoShow === true) {
            ModalUtil.showModal(this.myId);
        }
        $('#' + this.myId.toString()).on('hidden.bs.modal', function () {
            _this.reset();
            // do something…
            that.onClose.emit(true);
            // alert(that.myId);
            if (that.removeFromDomOnHide) {
                ModalUtil.removeModalFromDom(_this.myId);
            }
            if (_this.historyBackOnClose === true) {
                window.history.back();
            }
        });
        $('#' + this.myId.toString()).on('show.bs.modal', function () {
            _this.isShow = true;
            that.onShow.emit(true);
        });
        $('#' + this.myId.toString()).on('shown.bs.modal', function () {
            _this.isShown = true;
            that.onShown.emit(true);
        });
    };
    ModalComponent.prototype.ngAfterContentInit = function () {
    };
    // getExtraClass() {
    //   alert(this.modalSize);
    //   switch (this.modalSize) {
    //     case ModalSize.FULL_SCREEN :
    //       return 'modal-full-screen';
    //     case ModalSize.LARGE :
    //       return 'modal-lg';
    //     case ModalSize.SMALL :
    //       return 'modal-sm';
    //   }
    // }
    ModalComponent.prototype.showModal = function () {
        ModalUtil.showModal(this.myId, this.appendToBodyOnShow);
    };
    ModalComponent.prototype.hideModal = function () {
        ModalUtil.hideModal(this.myId, this.removeFromDomOnHide);
    };
    ModalComponent.prototype.ngOnChanges = function (changes) {
        if (changes.hasOwnProperty('modalSize')) {
            switch (this.modalSize) {
                case ModalSize.DEFAULT:
                    this.myModalSizeClass = '';
                    break;
                case ModalSize.FULL_SCREEN:
                    this.myModalSizeClass = 'modal-full-screen';
                    break;
                case ModalSize.FULL_WIDTH:
                    this.myModalSizeClass = 'modal-full-width';
                    break;
                case ModalSize.CUSTOM_WIDTH:
                    this.myModalSizeClass = '';
                    this.hasCustomWidth = true;
                    this.handleCustomWith();
                    break;
                case ModalSize.LARGE:
                    this.myModalSizeClass = 'modal-lg';
                    break;
                case ModalSize.X_LARGE:
                    this.myModalSizeClass = 'modal-xl';
                    break;
                case ModalSize.SMALL:
                    this.myModalSizeClass = 'modal-sm';
                    break;
            }
        }
    };
    ModalComponent.prototype.ngOnDestroy = function () {
        ModalUtil.hideModal(this.myId, true);
    };
    ModalComponent.prototype.handleCustomWith = function () {
        if (isNullOrUndefined(this.customWidthPercent)) {
            this.customWidthPercent = new WindowMedias();
        }
        if (isNullOrUndefined(this.customWidthPercent.xs)) {
            this.customWidthPercent.xs = this.defaultWidthPercent;
        }
        if (isNullOrUndefined(this.customWidthPercent.sm)) {
            this.customWidthPercent.sm = this.customWidthPercent.xs;
        }
        if (isNullOrUndefined(this.customWidthPercent.md)) {
            this.customWidthPercent.md = this.customWidthPercent.sm;
        }
        if (isNullOrUndefined(this.customWidthPercent.lg)) {
            this.customWidthPercent.lg = this.customWidthPercent.md;
        }
        if (isNullOrUndefined(this.customWidthPercent.xl)) {
            this.customWidthPercent.xl = this.customWidthPercent.lg;
        }
        if (WindowMediaUtil.isXl()) {
            this.currentWidthPercent = this.customWidthPercent.xl;
        }
        if (WindowMediaUtil.isLg()) {
            this.currentWidthPercent = this.customWidthPercent.lg;
        }
        if (WindowMediaUtil.isMd()) {
            this.currentWidthPercent = this.customWidthPercent.md;
        }
        if (WindowMediaUtil.isSm()) {
            this.currentWidthPercent = this.customWidthPercent.sm;
        }
        if (WindowMediaUtil.isXs()) {
            this.currentWidthPercent = this.customWidthPercent.xs;
        }
    };
    ModalComponent.prototype.getCssClasses = function () {
        var cssOptions = {};
        // // add the unique class
        // cssOptions[this.uniqueCssClass] = true;
        // this activates or deactivates the ::ng-deep CSS style
        cssOptions['not-display-modal-backdrop'] = !this.displayBackdrop;
        return cssOptions;
    };
    __decorate([
        Input()
    ], ModalComponent.prototype, "hasHeader", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "hasFooter", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "myId", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "autoShow", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "modalSize", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "customWidthPercent", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "historyBackOnClose", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "dataBackdrop", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "displayBackdrop", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "scrollLargeContents", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "modalDialogCentered", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "removeFromDomOnHide", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "appendToBodyOnShow", void 0);
    __decorate([
        Input()
    ], ModalComponent.prototype, "fade", void 0);
    __decorate([
        Output()
    ], ModalComponent.prototype, "onClose", void 0);
    __decorate([
        Output()
    ], ModalComponent.prototype, "onShow", void 0);
    __decorate([
        Output()
    ], ModalComponent.prototype, "onShown", void 0);
    ModalComponent = __decorate([
        Component({
            selector: 'nbw-modal',
            template: "<ng-container *ngIf=\"myId!==null && myId!==undefined\"></ng-container>\n<div class=\"modal\"\n     [class.fade]=\"fade\"\n     [ngClass]=\"getCssClasses()\"\n     [class.modal-full]=\"modalSize === MyModalSize.FULL_SCREEN\"\n     [id]=\"myId\" tabindex=\"-1\" role=\"dialog\"\n     data-id=\"{{myId}}\"\n     aria-labelledby=\"myLargeModalLabel\"\n     aria-hidden=\"true\"\n     [attr.data-backdrop]=\"dataBackdrop\">\n  <div class=\"modal-dialog\"\n       [class.modal-dialog-centered]=\"modalDialogCentered\"\n       [class.modal-dialog-scrollable]=\"scrollLargeContents\"\n       [class.modal-dialog-full]=\"modalSize === MyModalSize.FULL_SCREEN\"\n       [ngClass]=\"myModalSizeClass\" [ngStyle]=\"\n       hasCustomWidth === true && {'min-width': currentWidthPercent + '%'} ||\n       hasCustomWidth === true && {'margin': '0'}\n\">\n    <div class=\"modal-content\" [class.modal-content-full]=\"modalSize === MyModalSize.FULL_SCREEN\">\n      <ng-container *ngIf=\"hasHeader === true\">\n        <div class=\"modal-header\" [class.modal-header-full]=\"modalSize === MyModalSize.FULL_SCREEN\">\n          <div>\n            <ng-content select=\"[modal-header]\"></ng-content>\n          </div>\n          <div>\n            <button type=\"button\" class=\"close\"\n                    data-dismiss=\"modal\" aria-label=\"Close\">\n              <span aria-hidden=\"true\">&times;</span>\n            </button>\n          </div>\n        </div>\n\n\n      </ng-container>\n\n      <div class=\"modal-body\" [class.modal-body-full]=\"modalSize === MyModalSize.FULL_SCREEN\">\n        <ng-content select=\"[modal-body]\"></ng-content>\n      </div>\n      <ng-container *ngIf=\"hasFooter === true\">\n        <div class=\"modal-footer\" [class.modal-footer-full]=\"modalSize === MyModalSize.FULL_SCREEN\">\n          <ng-content select=\"[modal-footer]\"></ng-content>\n        </div>\n      </ng-container>\n\n    </div>\n  </div>\n</div>\n",
            styles: [".modal-full-screen{min-width:100%;margin:0}.modal-full-screen .modal-content{min-height:95vh}.modal-full-width{min-width:100%;margin:0}.not-display-modal-backdrop ::ng-deep .modal-backdrop{display:none}"]
        })
    ], ModalComponent);
    return ModalComponent;
}());

var WidgetsComponent = /** @class */ (function () {
    function WidgetsComponent() {
    }
    WidgetsComponent.prototype.ngOnInit = function () {
    };
    WidgetsComponent = __decorate([
        Component({
            selector: 'lib-widgets',
            template: "\n    <p>\n      widgets works!\n    </p>\n  "
        })
    ], WidgetsComponent);
    return WidgetsComponent;
}());

var noop$1 = function () {
};
var ɵ0$1 = noop$1;
var CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR$1 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return SwitchComponent; }),
    multi: true
};
var SwitchComponent = /** @class */ (function () {
    function SwitchComponent() {
        // The internal data model
        this.innerValue = '';
        // Placeholders for the callbacks which are later provided
        // by the Control Value Accessor
        this.onTouchedCallback = noop$1;
        this.onChangeCallback = noop$1;
    }
    Object.defineProperty(SwitchComponent.prototype, "value", {
        // get accessor
        get: function () {
            return this.innerValue;
        },
        // set accessor including call the onchange callback
        set: function (v) {
            if (v !== this.innerValue) {
                this.innerValue = v;
                this.onChangeCallback(v);
            }
        },
        enumerable: true,
        configurable: true
    });
    ;
    // Set touched on blur
    SwitchComponent.prototype.onBlur = function () {
        this.onTouchedCallback();
    };
    // From ControlValueAccessor interface
    SwitchComponent.prototype.registerOnChange = function (fn) {
        this.onChangeCallback = fn;
    };
    // From ControlValueAccessor interface
    SwitchComponent.prototype.registerOnTouched = function (fn) {
        this.onTouchedCallback = fn;
    };
    SwitchComponent.prototype.setDisabledState = function (isDisabled) {
    };
    // From ControlValueAccessor interface
    SwitchComponent.prototype.writeValue = function (value) {
        if (value !== this.innerValue) {
            this.innerValue = value;
        }
    };
    __decorate([
        Input()
    ], SwitchComponent.prototype, "rounded", void 0);
    __decorate([
        Input()
    ], SwitchComponent.prototype, "checked", void 0);
    SwitchComponent = __decorate([
        Component({
            selector: 'nbw-switch',
            template: "<!--<label class=\"switch\">-->\n<!--<input type=\"checkbox\">-->\n<!--<span class=\"slider\"></span>-->\n<!--</label>-->\n\n<!--<label class=\"switch\">-->\n<!--<input type=\"checkbox\" checked>-->\n<!--<span class=\"slider\"></span>-->\n<!--</label><br><br>-->\n\n<!--<label class=\"switch\">-->\n<!--<input type=\"checkbox\">-->\n<!--<span class=\"slider round\"></span>-->\n<!--</label>-->\n<label class=\"switch\">\n  <input type=\"checkbox\"\n         name=\"switch\"\n         [(ngModel)]=\"value\"\n         class=\"form-control\"\n         (blur)=\"onBlur()\"\n         ngDefaultControl>\n  <span class=\"slider round\"></span>\n</label>\n",
            providers: [CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR$1],
            styles: [".switch{position:relative;display:inline-block;width:60px;height:34px}.switch input{display:none}.slider{position:absolute;cursor:pointer;top:0;left:0;right:0;bottom:0;background-color:#ccc;transition:.4s}.slider:before{position:absolute;content:\"\";height:26px;width:26px;left:4px;bottom:4px;background-color:#fff;transition:.4s}input:checked+.slider{background-color:#0db670}input:focus+.slider{box-shadow:0 0 1px #0db670}input:checked+.slider:before{transform:translateX(26px)}.slider.round{border-radius:34px}.slider.round:before{border-radius:50%}"]
        })
    ], SwitchComponent);
    return SwitchComponent;
}());

var NbWidgetsModule = /** @class */ (function () {
    function NbWidgetsModule() {
    }
    NbWidgetsModule = __decorate([
        NgModule({
            declarations: [
                WidgetsComponent,
                JsonPrintComponent,
                // XmlPrintComponent,
                CarouselComponent,
                ModalComponent,
                SwitchComponent,
                AutoSearchInputComponent
            ],
            imports: [
                CommonModule,
                FormsModule
            ],
            exports: [
                WidgetsComponent,
                JsonPrintComponent,
                // XmlPrintComponent,
                CarouselComponent,
                ModalComponent,
                SwitchComponent,
                AutoSearchInputComponent
            ]
        })
    ], NbWidgetsModule);
    return NbWidgetsModule;
}());

/*
 * Public API Surface of widgets
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AutoSearchInputComponent, CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR, CarouselComponent, JsonPrintComponent, ModalComponent, ModalUtil, NbWidgetsModule, WidgetsComponent, WindowMediaUtil, WindowMedias, ɵ0, CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR$1 as ɵa, SwitchComponent as ɵb };
//# sourceMappingURL=angular-boot-widgets.js.map
